@@ -46,7 +46,7 @@ def AnnotationClient(
         If True, restricts pool of threads to max size, by default None. If None, defaults to requests package default.
     pool_maxsize : Int or None, optional
         Sets the max number of threads in the pool, by default None. If None, defaults to requests package default.
-    over_client: 
+    over_client:
         client to overwrite configuration with
     Returns
     -------
@@ -65,6 +65,7 @@ def AnnotationClient(
         annotation_common,
         annotation_api_versions,
         auth_header,
+        verify=verify,
     )
 
     AnnoClient = client_mapping[api_version]
@@ -261,7 +262,7 @@ class AnnotationClientV2(ClientBase):
         aligned_volume_name: str = None,
         write_permission: str = "PRIVATE",
         read_permission: str = "PUBLIC",
-        notice_text: str = None
+        notice_text: str = None,
     ):
         """Creates a new data table based on an existing schema
 
@@ -303,7 +304,7 @@ class AnnotationClientV2(ClientBase):
         write_permission: str, optional
             What permissions to give the table for writing.  One of
             PRIVATE: only you can write to this table (DEFAULT)
-            GROUP: only members that share a group with you can write (excluding some groups) 
+            GROUP: only members that share a group with you can write (excluding some groups)
             PUBLIC: Anyone can write to this table. Note all data is logged, and deletes are done
             by marking rows as deleted, so all data is always recoverable
         read_permission: str, optional
@@ -314,7 +315,7 @@ class AnnotationClientV2(ClientBase):
         notice_text: str, optional
             Text the user will see when querying this table. Can be used to warn users of flaws,
             and uncertainty in the data, or to advertise citations that should be used with this table.
-            Defaults to None, no text. If you want to remove text, send empty string. 
+            Defaults to None, no text. If you want to remove text, send empty string.
         Returns
         -------
         json
@@ -327,11 +328,10 @@ class AnnotationClientV2(ClientBase):
         voxel_res = [4,4,40]
         client.create_table("some_synapse_table", "synapse", description, voxel_res)
         """
-        if read_permission not in ["PRIVATE","GROUP","PUBLIC"]:
-            raise ValueError('read_permission must be one of PRIVATE GROUP or PUBLIC')
+        if read_permission not in ["PRIVATE", "GROUP", "PUBLIC"]:
+            raise ValueError("read_permission must be one of PRIVATE GROUP or PUBLIC")
         if write_permission not in ["PRIVATE", "GROUP", "PUBLIC"]:
-            raise ValueError('write_permission must be one of PRIVATE GROUP or PUBLIC')
-
+            raise ValueError("write_permission must be one of PRIVATE GROUP or PUBLIC")
 
         if aligned_volume_name is None:
             aligned_volume_name = self.aligned_volume_name
@@ -347,12 +347,12 @@ class AnnotationClientV2(ClientBase):
             "voxel_resolution_y": float(voxel_resolution[1]),
             "voxel_resolution_z": float(voxel_resolution[2]),
             "read_permission": read_permission,
-            "write_permission": write_permission
+            "write_permission": write_permission,
         }
         if user_id is not None:
             metadata["user_id"] = user_id
         if notice_text is not None:
-            metadata["notice_text"]=notice_text
+            metadata["notice_text"] = notice_text
         if reference_table is not None:
             metadata["table_metadata"] = {
                 "reference_table": reference_table,
@@ -364,7 +364,7 @@ class AnnotationClientV2(ClientBase):
         data = {
             "schema_type": schema_name,
             "table_name": table_name,
-            "metadata": metadata
+            "metadata": metadata,
         }
 
         response = self.session.post(url, json=data)
@@ -379,13 +379,13 @@ class AnnotationClientV2(ClientBase):
         write_permission: str = None,
         user_id: int = None,
         notice_text: str = None,
-        aligned_volume_name: str = None
+        aligned_volume_name: str = None,
     ):
         """update the metadata on an existing table
 
         Args:
             table_name (str): name of table to update
-            description (str, optional): text description of the the table. 
+            description (str, optional): text description of the the table.
                 Defaults to None (will not update).
             flat_segmentation_source (str, optional): cloudpath to a flat segmentation associated with this table.
                 Defaults to None (will not update).
@@ -398,13 +398,13 @@ class AnnotationClientV2(ClientBase):
             write_permission: str, optional
                 What permissions to give the table for writing.  One of
                 PRIVATE: only you can write to this table
-                GROUP: only members that share a group with you can write (excluding some groups) 
+                GROUP: only members that share a group with you can write (excluding some groups)
                 PUBLIC: Anyone can write to this table. Note all data is logged, and deletes are done
                 by marking rows as deleted, so all data is always recoverable
                 Defaults to None (will not update).
             user_id (int, optional): change ownership of this table to this user_id.
                 Note, if you use this you will not be able to update the metadata on this table any longer
-                and depending on permissions may not be able to read or write to it 
+                and depending on permissions may not be able to read or write to it
                 Defaults to None. (will not update)
             notice_text: str, optional
                 Text the user will see when querying this table. Can be used to warn users of flaws,
@@ -414,12 +414,15 @@ class AnnotationClientV2(ClientBase):
                 Name of the aligned_volume. If None, uses the one specified in the client.
         """
         if read_permission is not None:
-            if read_permission not in ["PRIVATE","GROUP","PUBLIC"]:
-                raise ValueError('read_permission must be one of PRIVATE GROUP or PUBLIC')
+            if read_permission not in ["PRIVATE", "GROUP", "PUBLIC"]:
+                raise ValueError(
+                    "read_permission must be one of PRIVATE GROUP or PUBLIC"
+                )
         if write_permission is not None:
             if write_permission not in ["PRIVATE", "GROUP", "PUBLIC"]:
-                raise ValueError('write_permission must be one of PRIVATE GROUP or PUBLIC')
-
+                raise ValueError(
+                    "write_permission must be one of PRIVATE GROUP or PUBLIC"
+                )
 
         if aligned_volume_name is None:
             aligned_volume_name = self.aligned_volume_name
@@ -429,25 +432,21 @@ class AnnotationClientV2(ClientBase):
 
         url = self._endpoints["tables"].format_map(endpoint_mapping)
 
-
         metadata = {}
         if description is not None:
-            metadata["description"]=description
+            metadata["description"] = description
         if read_permission is not None:
-            metadata["read_permission"]=read_permission
+            metadata["read_permission"] = read_permission
         if write_permission is not None:
-            metadata["write_permission"]=write_permission 
+            metadata["write_permission"] = write_permission
         if flat_segmentation_source is not None:
-            metadata["flat_segmentation_source"]=flat_segmentation_source            
+            metadata["flat_segmentation_source"] = flat_segmentation_source
         if user_id is not None:
             metadata["user_id"] = user_id
         if notice_text is not None:
             metadata["notice_text"] = notice_text
 
-        data = {
-            "table_name": table_name,
-            "metadata": metadata
-        }
+        data = {"table_name": table_name, "metadata": metadata}
         response = self.session.put(url, json=data)
         return handle_response(response, as_json=True)
 
